@@ -2,9 +2,6 @@ TranslationLanguage=Polski
 
 "Remote to local path mappings.~~Examples:~/share=\\pch\share~/var/downloads/music=Z:\music"="Mapowanie ścieżek zdalnych do lokalnych.~~Przykłady:~/share=\\pch\share~/var/downloads/music=Z:\music"
 %d x %s (have %d)=%d x %s (pobrano %d)
-%dd, %dh=%dd, %dg
-%dh, %dm=%dh, %dm
-%dm, %ds=%dm, %ds
 %ds=%ds
 %s (%d hashfails)=%s (%d błędów bufora)
 %s (%s done)=%s (%s pobrane)
@@ -28,7 +25,6 @@ Active=Aktywne
 Add new torrent=Dodaj nowy torrent
 &Add torrent=Dodaj torrent
 Added on=Dodane o
-All=Wszystkie
 Are you sure to remove torrent '%s' and all associated DATA?=Czy na pewno chcesz usunąć plik torrent '%s' oraz wszystkie pobrane dane?
 Are you sure to remove torrent '%s'?=Czy na pewno chcesz usunąć plik torrent '%s'?
 Authentication=Autoryzacja
@@ -40,16 +36,13 @@ Comment=Komentarz
 Completed on=Zakończono o
 Completed=Ukończono
 Confirmation=Potwierdzenie
-Connect to daemon=Podłącz do demona
 connected=połączono
 Connecting to daemon=Łączenie do demona
 Connection error occurred=Wystąpił błąd połączenia
-Connection=Połączenie
 Copy=Kopiuj
 Country=Kraj
 Created on=Utworzono o
 D: %s/s=D: %s/s
-Delete host settings=Usuń ustawienia hosta
 Destination folder=Folder docelowy
 Disconnected=Rozłącz
 Donate to support further development=Darowizna na wsparcie dalszego rozwoju
@@ -60,7 +53,6 @@ Down limit=Limit pobierania
 Down speed=Pobieranie
 Down=W dół
 Download complete=Zakończono pobieranie
-Download dir=Folder pobierania
 Download speed=Prędkość pobierania
 Downloaded=Pobrane
 Downloading=Pobieranie
@@ -96,7 +88,6 @@ Incoming port is closed. Check your firewall settings=Port połączeń przychodz
 Incoming port tested successfully=Test portu połączeń przychodzących wypadł pomyślnie
 Incoming port=Port połączeń przychodzących
 Information=Informacja
-Interface=Interfejs
 KB/s=KB/s
 KB=KB
 Language=Język
@@ -116,13 +107,10 @@ No to all=Nie na wszystko
 Normal priority=Normalny priorytet
 normal=normalny
 of=z
-OK=OK
 Open containing folder=Otwórz folder zawierający
 Open=Otwórz
-Options=Opcje
 Password=Hasło
 Paths=Ścieżki
-Pick random port on daemon launch=Losuj port przy uruchamianiu demona
 Peer limit=Limit peerów
 Peers=Peery
 Pieces=Części
@@ -135,7 +123,6 @@ Proxy server=Serwer proxy
 Proxy user name=Nazwa użytkownika proxy
 Ratio=Ratio
 Reconnect in %d seconds=Ponawianie próby za %d sekund
-Refresh interval=Częstotliwość odświeżania
 Remaining=Pozostało
 Remote host=Zdalny host
 Remove torrent and Data=Usuń torrenta razem z danymi
@@ -153,7 +140,6 @@ Select none=Odznacz wszystko
 Setup columns=Ustawienia kolumn
 Share ratio=Ratio współdzielenia
 Show country flag=Wyświetlaj flagi państw
-Show parameters window when adding a new torrent=Wyświetl okno właściwości po dodaniu torrenta
 Show=Pokaż
 Size=Rozmiar
 skip=pomiń
@@ -186,7 +172,6 @@ Tray icon always visible=Ikonka w trayu zawsze widoczna
 Tray icon=Ikonka w trayu
 U: %s/s=U: %s/s
 Unable to extract flag image=Nie można rozpakować obrazków flag
-Unable to find path mapping.~Use program's options to setup path mappings=Nie można znaleźć mapowania ścieżek.~Użyj opcji programu aby je ustawić
 Unable to get files list=Nie można pobrać listy plików
 Unknown=Nieznane
 Up limit=Limit wysyłania
@@ -198,7 +183,6 @@ Update in=Aktualizacja za
 Updating=Aktualizacja
 Upload speed=Prędkość wysyłania
 Uploaded=Wysłane
-Use proxy server=Używaj serwera proxy
 User name=Nazwa użytkownika
 Verify torrent=Zweryfikuj torrenta
 &Verify=Weryfikuj
@@ -209,9 +193,7 @@ Warning=Ostrzeżenie
 Wasted=Zmarnowane
 Working=Działa
 Yes to &All=Tak na &Wszystkie
-You should restart the application to apply changes=Uruchom ponownie aplikację aby zastosować zmiany
 No tracker=Brak trackera
-Tracker did not respond=tracker nie odpowiada
 %s downloaded=%s pobrano
 %s of %s downloaded=%s z %s pobrano
 %d torrents=%d torrenty
@@ -225,7 +207,6 @@ Download=Pobierz
 Enable blocklist=Włącz blocklistę
 ID=Nr
 Move torrent data from current location to new location=Przenieś dane tego torrenta do innej lokalizacji
-Network=Sieć
 New location for torrent data=Nowa lokalizacja na pobrane dane
 No link was specified=Link nie został podany
 No torrent location was specified=Nie została podana lokalizacja torrenta
@@ -243,7 +224,7 @@ Update blocklist=Uaktualnij blocklistę
 URL of a .torrent file or a magnet link=URL pliku .torrent lub magnet linka
 Columns setup=Ustawienia kolumn
 Add torrent=Dodaj torrent
-Delete a .torrent file after after a successful addition=Usuń plik .torrent po dodaniu
+Delete a .torrent file after a successful addition=Usuń plik .torrent po dodaniu
 Torrent=Torrent
 Torrents verification may take a long time.~Are you sure to start verification of %d torrents?=Weryfikacja torrentów może trwać bardzo długo.~Czy na pewno chcesz zweryfikować %d torrentów?
 Unable to load OpenSSL library files: %s and %s=Nie można załadować biblioteki OpenSSL: %s i %s
@@ -253,10 +234,8 @@ Alternate bandwidth settings=Alternatywne ustawienia łącza
 Apply alternate bandwidth settings automatically=Automatycznie włącz alternatywne ustawienia łącza
 Are you sure to delete connection '%s'?=Czy na pewno chcesz usunąć połączenie '%s'?
 Are you sure to remove tracker '%s'?=Czy na pewno chcesz usunąć tracker '%s'?
-Connection options=Ustawienia połączeń
 Days=Dni
 Delete=Usuń
-Disconnect=Rozłącz
 Disk cache size=Wielkość cache dysku
 Download speeds (KB/s)=Prędkości pobierania (KB/s)
 Edit tracker=Edytuj tracker
@@ -270,12 +249,10 @@ New connection=Nowe połączenie
 New=Nowy
 No tracker URL was specified=URL trackera nie został podany
 Proxy=Proxy
-Refresh interval when minimized=Częstotliwość odświeżania gdy zminimalizowany
 Remove tracker=Usuń tracker
 Rename=Zmień nazwę
 Speed limit menu items=Elementy menu ograniaczania prędkości
 Stop seeding when inactive for=Zakończ seedowanie gdy nieaktywny przez
-The blocklist URL was not specified=Adres URL blocklisty nie został podany
 The invalid time value was entered=Został podany niepoprawny czas
 to=do
 Tracker announce URL=URL Trackera
@@ -313,7 +290,6 @@ Queue=Kolejka
 Torrents that are idle for N minuets aren't counted toward the Download queue or Upload queue=Torrenty, które są bezczynne przez N minut, są pominięte z kolejki pobierania lub wysyłania
 Tracker grouping=Grupowanie trackerów
 Upload queue size=Rozmiar kolejki wysyłania
-User interface scaling=Skalowanie interfejsu użytkownika
 View=Widok
 Visit home page=Odwiedź stronę domową
 days=dni
@@ -328,3 +304,45 @@ Global statistics=Globalna statystyka
 Info pane=Panel informacji
 Statistics=Statystyka
 Status bar=Pasek stanu
+%dd=%dd
+%dh=%dh
+%dm=%dm
+All torrents=Wszystkie torrenty
+Application options=Opcje aplikacji
+Ask for password=Poproś o hasło
+Authentication required=Uwierzytelnianie wymagane
+Average out transfer speeds to eliminate fluctuations=Uśrednij prędkość transferu do wyeliminowania wahań
+Connect to %s=Połącz z %s
+Connect to Transmission using proxy server=Połącz z Transmission przy użyciu serwera proxy
+Connect to Transmission=Połącz z Transmission
+Connection name=Nazwa połączenia
+Could not connect to tracker==Nie można połączyć się z trackerem
+Data display=Wyświetlaj dane
+Data refresh interval when minimized=Interwał odświeżania danych gdy zminimalizowane
+Data refresh interval=Interwał odświeżania danych
+Default download folder on remote host=Domyślny folder pobrania na zdalnym hoście
+Disconnect from Transmission=Odłącz od Transmission
+Downloading torrent file=Pobieranie pliku torrent
+Font size=Rozmiar czcionki
+Handle .torrent files by %s=Obsługa plików .torrent przez %s
+Handle magnet links by %s=Obsługa linków magnet przez %s
+Invalid name specified=Określona nazwa jest nieprawidłowa 
+Manage connections to Transmission=Zarządzaj połączeniami do Transmission
+Manage connections=Zarządzaj połączeniami
+Network (WAN)=Sieć (WAN)
+New connection to Transmission=Nowe połączenie do Transmission
+Pick random port on Transmission launch=Wybierz losowy port przy uruchomieniu Transmission
+Please enter a password to connect to %s=Wprowadź hasło, aby połączyć się z %s
+Please specify how %s will connect to a remote host running Transmission daemon (service)=Proszę określić, jak %s połączy się usługą Transmission (daemonem) uruchomionym na zdalnym hoście
+Prompt for download options when adding a new torrent=Pytaj o opcje pobierania podczas dodawania nowego torrenta
+RPC path=ścieżka RPC
+Save as=Zapisz jako
+Seeding time=Czas seedowania
+Show advanced options=Pokaż opcje zaawansowane
+Show notifications in tray icon=Pokaż powiadomienia w ikonie na pasku
+System integration=Integracja systemu
+Torrent already exists in the list=Torrent już istnieje na liście
+Torrent not registered with this tracker==Torrent nie jest zarejestrowany na tym trackerze
+Unable to find path mapping.~Use the application's options to setup path mappings=Nie można znaleźć mapowania ścieżki.~Użyj opcji w aplikacji do konfiguracji mapowania ścieżki
+Update trackers for the existing torrent?=Uaktualnij trackery dla istniejącego torrenta?
+You need to restart the application to apply changes=Musisz ponownie uruchomić aplikację, aby zastosować zmiany
\ No newline at end of file
